import os
import pyilz.refresh_token as refresh_token


def get_token(ref_token=None):
    API_KEY = os.getenv('API_KEY')
    if API_KEY:
        return API_KEY
    else:
        print('No token found, refreshing...')
        API_KEY = refresh_token.refresh_token(ref_token)
        os.environ['API_KEY'] = API_KEY
    return API_KEY



import json
from pyilz.parse_land import parse_land
from pyilz.get_timers import get_timers
def test_e2e():
    # Get list of plots
    with open('./tests/example_game_state.json', 'r') as f:
        plots = json.load(f)['data']

    # Get Current, Automatic and Completed Actions
    land = plots[2]['data']
    _, _, ca, aa, completed = parse_land(land)

    # Get timers from actions
    timers = get_timers(ca, aa, completed)

    # If no exception, test passed
    assert True



import wmi
import hashlib
import pythoncom

def get_device_id():
    # Use CoInitialize to avoid errors like this:
    #    http://stackoverflow.com/questions/14428707/python-function-is-unable-to-run-in-new-thread
    pythoncom.CoInitialize()
    c = wmi.WMI()
    s = ""
    for item in c.query("SELECT * FROM Win32_BaseBoard"):
        s += item.SerialNumber
    for item in c.query("SELECT * FROM Win32_BIOS"):
        s += item.SerialNumber
    for item in c.query("SELECT * FROM Win32_OperatingSystem"):
        s += item.SerialNumber
    return hashlib.sha1(s.encode('utf-8')).hexdigest()

if __name__ == "__main__":
    print(get_device_id())


import json
import math
import importlib.resources
import json

with importlib.resources.open_text("pyilz", "buildings.json") as file:
    buildings = json.load(file)['buildings']


def get_active_output(name, level, tier, efficiency=100):
    name = name.lower().replace(' ', '').replace('_', '')
    land_tier_bonus_multiplier_percent = [0, 0, 33.33333333333, 100, 300, 900]
    for building in buildings:  # This should probably be a dict
        if building['nameId'] == name:
            details = building['details']
            for detail in details:
                if detail['level'] == level:
                    activities = detail['activities']
                    active = activities['active']
                    if active is None:
                        return 0
                    amount = int(active['amount'])
                    return math.ceil((amount * efficiency / 100) * (1 + (land_tier_bonus_multiplier_percent[tier] / 100)))


def get_passive_output(name, level, tier, efficiency=100):
    name = name.lower().replace(' ', '').replace('_', '')
    land_tier_bonus_multiplier_percent = [0, 0, 33.33333333333, 100, 300, 900]
    for building in buildings:  # This should probably be a dict
        if building['nameId'] == name:
            details = building['details']
            for detail in details:
                if detail['level'] == level:
                    activities = detail['activities']
                    passive = activities['passive']
                    if passive is None:
                        return 0
                    amount = int(passive['amount'])
                    return math.ceil((amount * efficiency / 100) * (1 + (land_tier_bonus_multiplier_percent[tier] / 100)))


if __name__ == '__main__':
    print('-- Active --')
    print(
        f'Level 5 Hydrogen Pump on Tier 2 Land at 150% efficiency: {get_active_output("Hydrogen Pump", 5, 2, 150)}')
    print(
        f'Level 6 Sequestrian Plant on Tier 2 Land at 150% efficiency: {get_active_output("Sequestrian Plant", 6, 2, 150)}')
    print(
        f'Level 6 Sequestrian Plant on Tier 3 Land at 150% efficiency: {get_active_output("Sequestrian Plant", 6, 3, 150)}')
    print('-- Passive --')
    print(
        f'Level 5 Hydrogen Pump on Tier 2 Land at 150% efficiency: {get_passive_output("Hydrogen Pump", 5, 2, 150)}')
    print(
        f'Level 6 Sequestrian Plant on Tier 2 Land at 150% efficiency: {get_passive_output("Sequestrian Plant", 6, 2, 150)}')
    print(
        f'Level 6 Sequestrian Plant on Tier 3 Land at 150% efficiency: {get_passive_output("Sequestrian Plant", 6, 3, 150)}')
